#
# spec file for package python-libeconf
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%define skip_python39 1
Name:           python-libeconf
Version:        0.7.7
Release:        1.1
Summary:        Python bindings for libeconf
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/openSUSE/libeconf
Source:         libeconf-%{version}.tar.xz
BuildArch:      noarch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
Requires:       libeconf0 = %{version}
Suggests:       python-libeconf-doc = %{version}
%python_subpackages

%description
Python bindings for libeconf

%package -n python-libeconf-doc
Summary:        Man page for python-libeconf

%description -n python-libeconf-doc
Man page for python-lineconf

%prep
%autosetup -n libeconf-%{version}/bindings/python3

%build
%pyproject_wheel

%install
%pyproject_install
mkdir -p %{buildroot}/usr/share/man/man3
cp docs/python-libeconf.3 %{buildroot}%{_mandir}/man3/

%files %python_files
%{python_sitelib}
# The cache is not always present
#pycache_only %{python_sitelib}/__pycache__

%files -n python-libeconf-doc
%defattr(-,root,root)
%{_mandir}/man3/*python-libeconf*

%changelog
* Mon Jan 13 2025 schubi@suse.com
- Update to version 0.7.7:
  * Additional fix for parsing empty config files (bsc#1234405).
* Fri Dec 13 2024 schubi@suse.com
- Update to version 0.7.6:
  * Do not try to parse files with name like ".." and "." (#227)
  * using econf_readConfig in econftool
* Mon Dec  9 2024 schubi@suse.com
- Update to version 0.7.5:
  * Removed PATH_MAX (Issue #220)
  * Add ROOT_PREFIX as option to replace TESTSDIR hack
  * CI: valgrind doesn't work together with sanitizers
  * econf_readConfig: don't allocate econf_file in error case
  * tests: use cleanup to free key_file for some tests
  * libeconf: don't allocate array from size 0
  * libeconf: fix use of uninitialized stat result if file does not exist
  * econftool: dynamically allocate xdg_config_dir
  * Disable clang <= 17, enable valgrind
  * Disable whitespace check
  * Disable deprecation warning for econftool and example
  * Add new CI with different compilers and valgrind
  * Test econf_readConfig()
  * Disable deprecation warning for tests
  * Implement econf_*freep functions for automatic cleanup
  * Cleanup *free functions
* Wed Oct  2 2024 Stefan Schubert <schubi@suse.com>
- Updated license in the spec file to MIT.
* Thu Sep 26 2024 schubi@suse.com
- Update to version 0.7.4:
  * fixed memory leaks (#219)
* Wed Sep 18 2024 schubi@suse.com
- Update to version 0.7.3:
  * Fixed: econf_readDirs crashes if one of the paths is NULL (#211)
  * Handle groups correctly which do not have any key entry.
  * Added links to man page. E.g. "man econf_readConfig" is working now.
  * Simplify snprintf call
  * Remove unused functions and reduce variable visibility (#213)
  * Fix typos (#212)
* Fri Jun 14 2024 schubi@suse.com
- Update to version 0.7.2:
  * Do not check errno while float conversion. This is a false
    alarm for S390 and PPC (#210).
* Mon Jun 10 2024 schubi@suse.com
- Update to version 0.7.1:
  * Improved error handling while parsing values with the wrong format.
  Added new return value ECONF_VALUE_CONVERSION_ERROR.
  * Setting parsing options via econf_file struct.
  see econf_newKeyFile_with_options. These options will be used by
  econf_readConfig and econf_readConfigWithCallback.
  Following options are supported:
  JOIN_SAME_ENTRIES  (default 0)
    Parsed entries with the same name will not be replaces but
    will be joined to one entry.
  PYTHON_STYLE  (default 0)
    E.G. Identations will be handled like multiline entries.
  PARSING_DIRS (default /usr/etc/:/run:/etc)
    List of directories from which the configuration files have to be parsed.
    The list is a string, divides by ":". The last entry has the highest
    priority. E.g.: "PARSING_DIRS=/usr/etc/:/run:/etc"
  CONFIG_DIRS (default <empty>)
    List of directory structures (with order) which describes the directories
    in which the files have to be parsed.
    The list is a string, divides by ":". The last entry has the highest
    priority. E.g. with the given list: "CONFIG_DIRS=.conf.d:.d" files in
    following directories will be parsed:
    "<default_dirs>/<config_name>.conf.d/"
    "<default_dirs>/<config_name>.d/"
    "<default_dirs>/<config_name>/"
  * CAUTION: From now on every econf_file element MUST be intialized if
    econf_readConfig and econf_readConfigWithCallback is used.
  Either with NULL or:
  econf_file *key_file = NULL;
  if (error = econf_newKeyFile_with_options(&key_file, "PYTHON_STYLE=1"))
  {
    fprintf (stderr, "ERROR: couldn't create new key file: %%s\n",
    econf_errString(error));
    return 1;
  }
  error = econf_readConfig (&key_file,
    "foo",
    "/usr/lib",
    "example",
    "conf",
    "=", "#");
* Tue Jun  4 2024 schubi@suse.com
- Update to version 0.7.0:
  * Defining manual parsing directories (#209)
  * parsing config files in python style
  * econf_readConfig: set usr_subdir to empty string if it is NULL
  * Fix static analyzer detected issues (#202)
  * comment string can be in the parsed value which is defined with quotes (#207)
  * tst-comments2: comment sign in quoted string (#205)
  * Setting options via new econf_newKeyFile_with_options. (#206)
* Fri Apr 12 2024 schubi@suse.com
- Update to version 0.6.3:
  * Fix build with musl libc on ppc64le (#198)
  * Creating static library with new package libeconf-devel-static.
    This is needed for building package util-linux and btrfsprogs.
* Wed Mar  6 2024 schubi@suse.com
- Update to version 0.6.2:
  * Fix static analyzer detected issues (#196)
* Mon Jan 22 2024 schubi@suse.com
- Update to version 0.6.1:
  * reading lines which have a length greater than BUFSIZE (#195)
  * Improved data quote check in read_file (#193)
* Mon Nov 13 2023 Alberto Planas Dominguez <aplanas@suse.com>
- Do not requires the library for the documentation
* Wed Nov  8 2023 Alberto Planas Dominguez <aplanas@suse.com>
- Fix version comparison operator
- Remove explicit python3-base requirement
* Fri Nov  3 2023 schubi@suse.com
- Update to version 1.1.1:
  * Supporting Linux Userspace API (UAPI) Group
    chapter "Configuration Files Specification".
    See: https://uapi-group.org/specifications/specs/
    configuration_files_specification/
* Fri Nov  3 2023 Alberto Planas Dominguez <aplanas@suse.com>
- Support only Python >= 3.10. PEP 604 is used for union types
* Fri Oct 27 2023 Nico Krapp <nico.krapp@suse.com>
- Version 1.1.0
  * Added tests
  * Support all functions form libeconf 0.5.2
  * Bug fixes
